==> cspace-public-browser-1.2.0-rc.1.tgz: package/src/components/search/result/SearchResultPanel.jsx <==
/* global window */

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Immutable from 'immutable';
import SearchParamList from './SearchParamList';
import SearchResultList from './SearchResultList';
import SearchResultStats from './SearchResultStats';
import SortSelect from '../entry/SortSelectContainer';
import { SORT_ID } from '../../../constants/ids';
import styles from '../../../../styles/cspace/SearchResultPanel.css';
import cssDimensions from '../../../../styles/dimensions.css';

const propTypes = {
  error: PropTypes.instanceOf(Error),
  isPending: PropTypes.bool,
  offset: PropTypes.number,
  onHitsUpdated: PropTypes.func,
  result: PropTypes.instanceOf(Immutable.Map),
  params: PropTypes.instanceOf(Immutable.Map),
  search: PropTypes.func,
  setSearchPageSize: PropTypes.func,
};

const defaultProps = {
  error: undefined,
  isPending: false,
  offset: undefined,
  onHitsUpdated: undefined,
  params: Immutable.Map(),
  result: undefined,
  search: () => undefined,
  setSearchPageSize: () => undefined,
};

const {
  searchResultTileWidth: cssTileWidth,
  searchResultTileBodyHeight: cssTileBodyHeight,
} = cssDimensions;

const tileWidth = parseInt(cssTileWidth, 10);
const tileBodyHeight = parseInt(cssTileBodyHeight, 10);
const tileHeight = tileWidth + tileBodyHeight;

const calculateSearchPageSize = () => {
  const width = window.innerWidth;
  const height = window.innerHeight;
  const ratio = window.devicePixelRatio || 1;
  const pageSize = ((width / tileWidth) * (height / tileHeight + 2)) / ratio;

  return Math.max(Math.ceil(pageSize), 12);
};

export default class SearchResultPanel extends Component {
  constructor() {
    super();

    this.handleScroll = this.handleScroll.bind(this);

    this.ref = React.createRef();
  }

  componentDidMount() {
    const {
      setSearchPageSize,
    } = this.props;

    window.addEventListener('scroll', this.handleScroll, false);

    setSearchPageSize(calculateSearchPageSize());

    this.search();
  }

  componentDidUpdate(prevProps) {
    const {
      params,
    } = this.props;

    const {
      params: prevParams,
    } = prevProps;

    if (params !== prevParams) {
      this.search();
    }
  }

  componentWillUnmount() {
    window.removeEventListener('scroll', this.handleScroll, false);
  }

  handleScroll() {
    const {
      search,
    } = this.props;

    const rect = this.ref.current.getBoundingClientRect();
    const bottomOffset = rect.bottom - window.innerHeight;

    if (bottomOffset <= tileHeight) {
      search();
    }
  }

  search() {
    const {
      search,
    } = this.props;

    search();
  }

  renderError() {
    const {
      error,
    } = this.props;

    return (
      <div>{error.message}</div>
    );
  }

  renderResult() {
    const {
      isPending,
      offset,
      onHitsUpdated,
      params,
      result,
    } = this.props;

    return (
      <>
        <header>
          <SearchParamList params={params} />

          <div>
            <SearchResultStats count={result && result.get('total')} />
            <SortSelect value={params.get(SORT_ID)} />
          </div>
        </header>

        <SearchResultList
          isPending={isPending}
          offset={offset}
          onHitsUpdated={onHitsUpdated}
          params={params}
          hits={result && result.get('hits')}
        />
      </>
    );
  }

  render() {
    const {
      error,
    } = this.props;

    return (
      <div className={styles.common} ref={this.ref}>
        {error ? this.renderError() : this.renderResult()}
      </div>
    );
  }
}

SearchResultPanel.propTypes = propTypes;
SearchResultPanel.defaultProps = defaultProps;

==> cspace-public-browser-1.5.0.tgz: package/src/components/search/result/SearchResultPanel.jsx <==
/* global window */

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Immutable from 'immutable';
import SearchParamList from './SearchParamList';
import SearchResultList from './SearchResultList';
import SearchResultStats from './SearchResultStats';
import SortSelect from '../entry/SortSelectContainer';
import config from '../../../config';
import { SORT_ID } from '../../../constants/ids';
import { calculateSearchPageSize, tileHeight } from '../../../helpers/searchDimensions';
import styles from '../../../../styles/cspace/SearchResultPanel.css';

const propTypes = {
  error: PropTypes.instanceOf(Error),
  isPending: PropTypes.bool,
  nextOffset: PropTypes.number,
  onHitsUpdated: PropTypes.func,
  result: PropTypes.instanceOf(Immutable.Map),
  params: PropTypes.instanceOf(Immutable.Map),
  search: PropTypes.func,
  setSearchPageSize: PropTypes.func,
};

const defaultProps = {
  error: undefined,
  isPending: false,
  nextOffset: undefined,
  onHitsUpdated: undefined,
  params: Immutable.Map(),
  result: undefined,
  search: () => undefined,
  setSearchPageSize: () => undefined,
};

export default class SearchResultPanel extends Component {
  constructor() {
    super();

    this.handleLoadMoreClick = this.handleLoadMoreClick.bind(this);
    this.handleScroll = this.handleScroll.bind(this);

    this.ref = React.createRef();
  }

  componentDidMount() {
    const {
      setSearchPageSize,
    } = this.props;

    window.addEventListener('scroll', this.handleScroll, false);

    setSearchPageSize(calculateSearchPageSize());

    this.search();
  }

  componentDidUpdate(prevProps) {
    const {
      params,
    } = this.props;

    const {
      params: prevParams,
    } = prevProps;

    if (params !== prevParams) {
      this.search();
    }
  }

  componentWillUnmount() {
    window.removeEventListener('scroll', this.handleScroll, false);
  }

  handleLoadMoreClick() {
    this.search();
  }

  handleScroll() {
    const {
      nextOffset,
    } = this.props;

    if (nextOffset < config.get('pageAutoLoadLimit')) {
      const {
        search,
      } = this.props;

      const rect = this.ref.current.getBoundingClientRect();
      const bottomOffset = rect.bottom - window.innerHeight;

      if (bottomOffset <= tileHeight) {
        search(config.get('pageLoadDelay'));
      }
    }
  }

  search(fetchDelay) {
    const {
      search,
    } = this.props;

    search(fetchDelay);
  }

  renderError() {
    const {
      error,
    } = this.props;

    return (
      <div>{error.message}</div>
    );
  }

  renderResult() {
    const {
      error,
      isPending,
      nextOffset,
      onHitsUpdated,
      params,
      result,
    } = this.props;

    const hitCount = result && result.get('total');
    const hits = result && result.get('hits');

    const showLoadMore = result
      && hits.size < hitCount
      && nextOffset >= config.get('pageAutoLoadLimit');

    return (
      <>
        <header>
          <SearchParamList params={params} />

          <div>
            <SearchResultStats count={hitCount} />
            <SortSelect value={params.get(SORT_ID)} />
          </div>
        </header>

        <SearchResultList
          error={error}
          isPending={isPending}
          onHitsUpdated={onHitsUpdated}
          onLoadMoreClick={this.handleLoadMoreClick}
          params={params}
          hits={hits}
          showLoadMore={showLoadMore}
        />
      </>
    );
  }

  render() {
    return (
      <div className={styles.common} ref={this.ref}>
        {this.renderResult()}
      </div>
    );
  }
}

SearchResultPanel.propTypes = propTypes;
SearchResultPanel.defaultProps = defaultProps;
